/*
 * Copyright 2021 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.tomee.vestige.launcher;

import java.io.Serializable;
import java.util.List;

/**
 * @author Gael Lalire
 */
public class WarInEar implements Serializable {

    private static final long serialVersionUID = -2045167968804446530L;

    private String javaVersion;

    private String groupId;

    private String artifactId;

    private String version;

    private String classifier;

    private String entryName;

    private WarVerificationMetadata verificationMetadata;

    private List<WarLibExclusion> warLibExclusions;

    public WarInEar(final String entryName, final String groupId, final String artifactId, final String version, final String classifier, final String javaVersion,
            final WarVerificationMetadata verificationMetadata, final List<WarLibExclusion> warLibExclusions) {
        this.entryName = entryName;
        this.groupId = groupId;
        this.artifactId = artifactId;
        this.version = version;
        this.classifier = classifier;
        this.javaVersion = javaVersion;
        this.verificationMetadata = verificationMetadata;
        this.warLibExclusions = warLibExclusions;
    }

    public String getEntryName() {
        if (entryName == null) {
            return artifactId + ".war";
        }
        return entryName;
    }

    public String getGroupId() {
        return groupId;
    }

    public String getArtifactId() {
        return artifactId;
    }

    public String getVersion() {
        return version;
    }

    public String getClassifier() {
        return classifier;
    }

    public String getJavaVersion() {
        return javaVersion;
    }

    public WarVerificationMetadata getVerificationMetadata() {
        return verificationMetadata;
    }

    public List<WarLibExclusion> getWarLibExclusions() {
        return warLibExclusions;
    }
}
