/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.loader;

import java.io.File;
import java.net.URL;

public final class OpenEJBLoaderControllerHandler {

    public static final ThreadLocal<OpenEJBLoaderController> OPEN_EJB_LOADER_CONTROLLER_THREAD_LOCAL = new InheritableThreadLocal<OpenEJBLoaderController>();

    public static final OpenEJBLoaderController DEFAULT_OPEN_EJB_LOADER_CONTROLLER = new OpenEJBLoaderController() {

        @Override
        public File toFile(URL url) {
            return null;
        }

    };

    private OpenEJBLoaderControllerHandler() {
    }

    public static void setOpenEJBCoreController(final OpenEJBLoaderController tomcatController) {
        OPEN_EJB_LOADER_CONTROLLER_THREAD_LOCAL.set(tomcatController);
    }

    public static OpenEJBLoaderController getOpenEJBCoreController() {
        OpenEJBLoaderController tomcatController = OPEN_EJB_LOADER_CONTROLLER_THREAD_LOCAL.get();
        if (tomcatController == null) {
            return DEFAULT_OPEN_EJB_LOADER_CONTROLLER;
        }
        return tomcatController;
    }
}
